@@ -1,13 +1,17 @@
+/* 
+ * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
+ *
+ * for details see file COPYING in the DOSEMU distribution
+ */
+
 #define EXTERN 
 #define INIT(x...)		=  ## x
 
-#ifndef lint
-static char *id= "$Id: data.c,v 1.4 1995/04/08 22:29:37 root Exp $";
-#endif
-
 #include <termios.h>
 #include <sys/types.h>
+#include "config.h"
 #include "emu.h"
+#include "mapping.h"
 #include "xms.h"
 #include "disks.h"
 #include "timers.h"
@@ -16,6 +20,7 @@ static char *id= "$Id: data.c,v 1.4 1995/04/08 22:29:37 root Exp $";
 #include "termio.h"
 #include "machcompat.h"
 #include "vc.h"
+#include "../env/video/vga.h" /* NOTE: there exists also /usr/include/vga.h !! */
 #include "video.h"
 #include "mouse.h"
 #include "bios.h"
@@ -28,3 +33,7 @@ static char *id= "$Id: data.c,v 1.4 1995/04/08 22:29:37 root Exp $";
 #include "priv.h"
 #include "dma.h"
 #include "sound.h"
+#include "serial.h"
+#include "dosemu_debug.h"
+#include "keyb_server.h"
+#include "keyb_clients.h"
