@@ -1,12 +1,9 @@
 /* 
- * (C) Copyright 1992, ..., 1999 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
 
-#ifdef __NetBSD__
-#define EDEADLOCK EDEADLK
-#endif
 
 #include <features.h>
 #include <stdio.h>
@@ -28,11 +25,6 @@
 #include <limits.h>
 #include <assert.h>
 
-#ifdef __NetBSD__
-#include <signal.h>
-#include <machine/pcvt_ioctl.h>
-#include "netbsd_vm86.h"
-#endif
 #ifdef __linux__
 #include <signal.h>
 #if GLIBC_VERSION_CODE >= 2000
@@ -48,19 +40,6 @@
 
 #include <sys/socket.h>
 #include <sys/ioctl.h>
-#ifndef __NetBSD__
-#include <linux/if_ether.h>
-#endif
-#ifdef __NetBSD__
-#include <sys/mman.h>
-#else
-extern caddr_t mmap __P ((caddr_t __addr, size_t __len,
-                          int __prot, int __flags, int __fd, off_t __off));
-                          extern int munmap __P ((caddr_t __addr, size_t
-__len));
-#include <linux/mman.h>
-#endif
-
 
 
 #include "config.h"
@@ -88,9 +67,6 @@ __len));
 #include "bitops.h"
 #include "pic.h"
 #include "dpmi.h"
-#ifdef __NetBSD__
-#include <setjmp.h>
-#endif
 
 #include "keyb_clients.h"
 
@@ -112,7 +88,7 @@ inline int process_interrupt(SillyG_t *sg);
 
 
 void io_select_init(void);
-#if defined(SIG) && defined(REQUIRES_VM86PLUS)
+#if defined(SIG)
 int SillyG_pendind_irq_bits=0;
 
 int SillyG_do_irq(void)
@@ -130,13 +106,13 @@ inline int process_interrupt(SillyG_t *sg)
 
   if ((irq = sg->irq) != 0) {
     h_printf("INTERRUPT: 0x%02x\n", irq);
-    ret=pic_request(pic_irq_list[irq]);
+    ret=(pic_request(pic_irq_list[irq])==PIC_REQ_OK);
   }
   return ret;
 }
 
 
-#if defined(SIG) && defined(REQUIRES_VM86PLUS)
+#if defined(SIG)
 inline void irq_select()
 {
   if (SillyG) {
@@ -161,6 +137,8 @@ inline void irq_select()
 /*  */
 /* io_select @@@  24576 MOVED_CODE_BEGIN @@@ 01/23/96, ./src/base/misc/dosio.c --> src/base/misc/ioctl.c  */
 
+static int numselectfd= 0;
+
 void
 io_select(fd_set fds)
 {
@@ -170,11 +148,11 @@ io_select(fd_set fds)
   tvptr.tv_sec=0L;
   tvptr.tv_usec=0L;
 
-#if defined(SIG) && defined(REQUIRES_VM86PLUS)
+#if defined(SIG)
   irq_select();
 #endif
 
-  while ( ((selrtn = select(25, &fds, NULL, NULL, &tvptr)) == -1)
+  while ( ((selrtn = select(numselectfd, &fds, NULL, NULL, &tvptr)) == -1)
         && (errno == EINTR)) {
     tvptr.tv_sec=0L;
     tvptr.tv_usec=0L;
@@ -207,6 +185,11 @@ io_select(fd_set fds)
 	extern void uhook_input(void);
 	if (uhook_fdin != -1) if (FD_ISSET(uhook_fdin, &fds)) uhook_input();
       }
+
+      /* here we include the hooks to possible plug-ins */
+      #include "plugin_ioselect.h"
+
+
 #ifdef USE_MHPDBG
       if (mhpdbg.fdin != -1) if (FD_ISSET(mhpdbg.fdin, &fds)) mhp_input();
 #endif
@@ -260,6 +243,7 @@ io_select_init(void) {
 void 
 add_to_io_select(int new_fd, u_char want_sigio)
 {
+    if ((new_fd+1) > numselectfd) numselectfd = new_fd+1;
     if (use_sigio && want_sigio) {
 	int             flags;
 	flags = fcntl(new_fd, F_GETFL);
