@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 1999 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -14,6 +14,7 @@
 
 #include <features.h>
 #include <sys/types.h>
+#include <setjmp.h>
 #if GLIBC_VERSION_CODE == 2000
 #include <sigcontext.h>
 #endif
@@ -46,14 +47,11 @@ typedef struct { int fd; int irq; } SillyG_t;
  * DANG_END_REMARK
 */ 
 
-#ifdef REQUIRES_VM86PLUS
-  EXTERN struct vm86plus_struct vm86s INIT ( {
+EXTERN struct vm86plus_struct vm86s INIT ( {
    {0},0,0,0,{{0}},{{0}}, {0}
-  } );
-#else
-  EXTERN struct vm86_struct vm86s;
-#endif
+} );
 
+EXTERN volatile sig_atomic_t signal_pending INIT(0);
 EXTERN fd_set fds_sigio, fds_no_sigio;
 EXTERN unsigned int use_sigio INIT(0);
 EXTERN unsigned int not_use_sigio INIT(0);
@@ -71,6 +69,11 @@ EXTERN int screen, screen_mode;
 /* number of highest vid page - 1 */
 EXTERN int max_page INIT(7);
 
+#if 0
+/*
+ * 1) this stuff is unused
+ * 2) it should be FORBIDDEN to use global names less than 4 chars long!
+ */
 EXTERN char *cl,		/* clear screen */
 *le,				/* cursor left */
 *cm,				/* goto */
@@ -87,11 +90,12 @@ EXTERN char *cl,		/* clear screen */
 *ke,				/* ens keys */
 *vi,				/* cursor invisible */
 *ve;				/* cursor normal */
+#endif
 
 /* the fd for the keyboard */ 
 EXTERN int console_fd INIT(-1);
 
-/* the file descriptor for /dev/mem when mmap'ing the video mem */
+/* the file descriptor for /dev/mem mmap'ing */
 EXTERN int mem_fd INIT(-1);
 EXTERN int in_readkeyboard;
 
@@ -109,10 +113,14 @@ EXTERN int cursor_col;
 #if 0
 void dos_ctrl_alt_del(void);	/* disabled */
 #endif
+extern jmp_buf NotJEnv;
 
 EXTERN void run_vm86(void);
+EXTERN void loopstep_run_vm86(void);
 EXTERN void     vm86_GP_fault();
 
+EXTERN void do_call_back(Bit32u codefarptr);
+
 #define NOWAIT  0
 #define WAIT    1
 #define TEST    2
@@ -135,7 +143,10 @@ void getKeys(void);
 
      int set_ioperm(int, int, int);
 
-EXTERN struct debug_flags d INIT({0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0});
+EXTERN struct debug_flags d INIT({0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0});
+#ifdef DONT_DEBUG_BOOT
+EXTERN struct debug_flags d_save;
+#endif
  
 EXTERN u_char in_sighandler, in_ioctl;
 /* one-entry queue ;-( for ioctl's */
@@ -277,6 +288,7 @@ typedef struct vesamode_type_struct {
        boolean keybint;
        boolean dosbanner;
        boolean allowvideoportaccess;
+       boolean emuretrace;
        boolean rdtsc;
        boolean timers;
        boolean mouse_flag;
@@ -330,6 +342,9 @@ typedef struct vesamode_type_struct {
        char *tty_lockfile;	/* Lock file pretext ie LCK.. */
        boolean tty_lockbinary;	/* Binary lock files ? */
 
+       /* type of mapping driver */
+       char *mappingdriver;
+
        /* list of arbitrary features
         * (at minimum 1, will be increased when needed)
         * The purpose of these parameters is to switch between code
@@ -426,10 +441,7 @@ EXTERN void sigquit(int);
 #ifdef __linux__
 EXTERN void sigalrm(int, struct sigcontext_struct);
 EXTERN void sigio(int, struct sigcontext_struct);
-#endif
-#ifdef __NetBSD__
-EXTERN void sigalrm(int, int, struct sigcontext *);
-EXTERN void sigio(int, int, struct sigcontext *);
+EXTERN int dosemu_sigaction(int sig, struct sigaction *new, struct sigaction *old);
 #endif
 
 /* signals for Linux's process control of consoles */
@@ -472,29 +484,6 @@ do { \
        sigaddset(x, SIG_ACQUIRE); \
 } while(0)
 
-#ifdef __NetBSD__
-#define SignalHandler sig_t
-#define __sighandler_t sig_t
-
-#define NEWSETQSIG(sig, fun)	sa.sa_handler = (__sighandler_t)fun; \
-					sa.sa_flags = SA_RESTART|SA_ONSTACK ; \
-					sigemptyset(&sa.sa_mask); \
-					ADDSET_SIGNALS_THAT_QUEUE(&sa.sa_mask); \
-					sigaction(sig, &sa, NULL);
-
-#define SETSIG(sig, fun)	sa.sa_handler = (__sighandler_t)fun; \
-					sa.sa_flags = SA_RESTART; \
-					sigemptyset(&sa.sa_mask); \
-					sigaddset(&sa.sa_mask, SIG_TIME); \
-					sigaction(sig, &sa, NULL);
-
-#define NEWSETSIG(sig, fun) \
-			sa.sa_handler = (__sighandler_t) fun; \
-			sa.sa_flags = SA_RESTART|SA_ONSTACK; \
-			sigemptyset(&sa.sa_mask); \
-			sigaddset(&sa.sa_mask, SIG_TIME); \
-			sigaction(sig, &sa, NULL);
-#endif
 #ifdef __linux__
 #if GLIBC_VERSION_CODE
 #define SignalHandler __sighandler_t
@@ -560,10 +549,6 @@ EXTERN int fatalerr INIT(0);
 EXTERN int running_DosC INIT(0);
 EXTERN int dosc_interface(void);
 
-#ifdef __NetBSD__
-#define iopl(value)			{ EXTERN int errno; if (i386_iopl(value) == -1) { g_printf("iopl failed: %s\n", strerror(errno)); leavedos(4);}}
-#endif
-
 EXTERN void signal_init(void);
 EXTERN void device_init(void);
 EXTERN void hardware_setup(void);
@@ -585,6 +570,6 @@ EXTERN void read_next_scancode_from_queue (void);
 EXTERN unsigned short detach (void);
 EXTERN void HMA_init(void);
 
-extern char path_cdrom[];
+extern char *Path_cdrom[];
 
 #endif /* EMU_H */
